import { TestModel } from "@xstate/test";
import { TestPlan } from "@xstate/test/lib/types";
import { Deferred } from "./delay";
export declare type Delay = ["delay" | "wait" | "...", number];
export declare type TestContextFunction<TTestContext> = (testContext: TTestContext) => unknown;
export declare type WaitForSelector = ["$" | "waitForSelector", string | string[]];
export declare type WaitForFocus = ["waitForFocus" | "$:focus", string];
export declare type Click = ["click", string | string[]];
export declare type Defer = ["defer", string | string[]];
export declare type Resolve = ["resolve", string | string[]];
export declare type Type = ["type", string, number | string];
export declare type Select = ["select", string, number | string | (number | string)[]];
export declare type ExpectProperty = [
    "expectProperty" | "prop" | ".",
    string,
    string,
    number | boolean | string
];
export declare type Instruction<TTestContext> = Delay | TestContextFunction<TTestContext> | WaitForSelector | WaitForFocus | Click | Defer | Resolve | Type | Select | ExpectProperty;
export declare type Configuration<TTestContext> = {
    id: string;
    visit: {
        port?: number;
        server?: string;
        path: string;
    };
    coverage?: boolean;
    simple?: boolean;
    path?: number | [number, number];
    plan?: number | [number, number];
    apis?: {
        path: string;
        status?: number;
        body?: any;
        deferrals?: string[];
        outcomes?: {
            [event: string]: {
                status?: number;
                body?: any;
            };
        };
    }[];
    viewport?: {
        width: number;
        height: number;
    };
    beforeVisit?: TestContextFunction<TTestContext> | Instruction<TTestContext>[];
    initial: string;
    states: {
        [state: string]: {
            type?: "final";
            tests?: TestContextFunction<TTestContext> | Instruction<TTestContext>[];
            on?: {
                [event: string]: string | TestContextFunction<TTestContext> | Instruction<TTestContext>[] | {
                    target?: string;
                    actions?: TestContextFunction<TTestContext> | Instruction<TTestContext>[];
                };
            };
        };
    };
};
export declare type Action<TTestContext> = Instruction<TTestContext>;
declare const _default: <TTestContext>(json: any) => import("fp-ts/lib/Either").Either<import("io-ts/lib/FreeSemigroup").FreeSemigroup<import("io-ts/lib/DecodeError").DecodeError<string>>, Configuration<TTestContext>>;
export default _default;
declare const defaultSelectorWrapper: (selector: string) => string;
declare type Options = {
    selectorWrapper?: (selector: string) => string;
    server?: string;
    xstateInspect?: boolean;
    ports?: {
        ci?: number;
        prod?: number;
        dev?: number;
    };
};
export declare const make: <TTestContext>(actionsParser: (selectorWrapper: typeof defaultSelectorWrapper) => (buffer: Deferred[]) => (actions: Instruction<TTestContext>[]) => (testContext: TTestContext) => Promise<any>) => (withPlans: (setup: {
    model: TestModel<TTestContext, any>;
    buffer: Deferred<any>[];
    config: Configuration<TTestContext>;
    outcomes: string[];
    pattern: string[][][];
    plans: TestPlan<TTestContext, unknown>[];
    url: string;
    selectorWrapper: typeof defaultSelectorWrapper;
}) => void) => ({ selectorWrapper, ports: ports_, server, xstateInspect, }?: Options) => (configuration: Configuration<TTestContext>) => void;
